{ stdenv, pkgs, fetchurl, lib, unzip, autoPatchelfHook, makeWrapper, ... }:

stdenv.mkDerivation rec {
  pname = "Amp Locker";
  version = "latest";
  src = fetchurl {
    url = "https://audioassaultdownloads.s3.amazonaws.com/AmpLocker/AmpLocker109/AmpLockerLinux.zip";
    sha256 = "sha256-adHle4A59DxJFR3KiLyuZp79vUK0QkGDnHRu6PWMVJQ=";
  };
  nativeBuildInputs = [ makeWrapper unzip autoPatchelfHook ];
  buildInputs = with pkgs; [
    freetype
    fontconfig
    alsa-lib
    pipewire
    curl
    stdenv.cc.cc.lib
  ];

  unpackPhase = ''
    unzip $src
  '';

  installPhase = ''
    mkdir -p $out/lib/vst3 $out/
    mv "Amp Locker.vst3/Contents/x86_64-linux/Amp Locker.so" "Amp Locker.vst3/Contents/x86_64-linux/AmpLocker.so"
    cp -r "Amp Locker.vst3" $out/lib/vst3/AmpLocker.vst3
  '';

  NIX_LDFLAGS = (toString [
    "-lX11"
    "-lXext"
    "-lXcursor"
    "-lXinerama"
    "-lXrandr"
  ]);

  postFixup = ''
    for file in \
      $out/lib/vst3/AmpLocker.vst3/Contents/x86_64-linux/AmpLocker.so
    do
      patchelf --set-rpath "${lib.makeLibraryPath buildInputs}" $file
    done
  '';

  meta = with lib; {
    homepage = "https://audioassault.mx/getamplocker#Get_Amp_Locker";
    description = "Amp Locker";
    platforms = platforms.linux;
  };
}
