{ stdenv, pkgs, fetchurl, lib, unzip, autoPatchelfHook, makeWrapper, ... }:

stdenv.mkDerivation rec {
  pname = "tal-j8";
  version = "latest";
  src = fetchurl {
    url = "https://tal-software.com/downloads/plugins/TAL-J-8_64_linux.zip";
    sha256 = "sha256-gBzlkqBzWHv1QhbzzOb2uWy1eyvPQqyRQzXMKWIunCc=";
  };
  nativeBuildInputs = [ makeWrapper unzip autoPatchelfHook ];
  buildInputs = with pkgs; [
    freetype
    fontconfig
    alsa-lib
    pipewire
    stdenv.cc.cc.lib
  ];

  unpackPhase = ''
    unzip $src
  '';

  installPhase = ''
    mkdir -p $out/lib/vst $out/lib/vst3 $out/lib/clap
    cp -r TAL-J-8/TAL-J-8.clap $out/lib/clap
    cp -r TAL-J-8/libTAL-J-8.so $out/lib/vst
    cp -r TAL-J-8/TAL-J-8.vst3 $out/lib/vst3
  '';

  postFixup = ''
    for file in \
      $out/lib/clap/TAL-J-8.clap \
      $out/lib/vst/libTAL-J-8.so \
      $out/lib/vst3/TAL-J-8.vst3/Contents/x86_64-linux/TAL-J-8.so
    do
      patchelf --set-rpath "${lib.makeLibraryPath buildInputs}" $file
    done
  '';

  meta = with lib; {
    homepage = "https://tal-software.com/products/tal-j-8";
    description = "TAL-J-8";
    platforms = platforms.linux;
  };
}
